@@ -1,7 +1,7 @@
 /* -*- Mode: c; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
 
     libparted - a library for manipulating disk partitions
-    Copyright (C) 2000-2001, 2007-2009 Free Software Foundation, Inc.
+    Copyright (C) 2000-2001, 2007-2011 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -153,7 +153,7 @@ bsd_probe (const PedDevice *dev)
 {
 	BSDRawLabel	*partition;
 
-	PED_ASSERT (dev != NULL, return 0);
+	PED_ASSERT (dev != NULL);
 
         if (dev->sector_size < 512)
                 return 0;
@@ -179,7 +179,7 @@ bsd_alloc (const PedDevice* dev)
 	BSDDiskData*	bsd_specific;
 	BSDRawLabel*	label;
 
-	PED_ASSERT(dev->sector_size % PED_SECTOR_SIZE_DEFAULT == 0, return 0);
+	PED_ASSERT(dev->sector_size % PED_SECTOR_SIZE_DEFAULT == 0);
 
 	disk = _ped_disk_alloc ((PedDevice*)dev, &bsd_disk_type);
 	if (!disk)
@@ -254,20 +254,6 @@ bsd_free (PedDisk* disk)
 	_ped_disk_free (disk);
 }
 
-#ifndef DISCOVER_ONLY
-static int
-bsd_clobber (PedDevice* dev)
-{
-	void *label;
-	if (!ptt_read_sector (dev, 0, &label))
-		return 0;
-	BSDRawLabel *rawlabel
-	  = (BSDRawLabel *) ((char *) label + BSD_LABEL_OFFSET);
-	rawlabel->d_magic = 0;
-	return ped_device_write (dev, label, 0, 1);
-}
-#endif /* !DISCOVER_ONLY */
-
 static int
 bsd_read (PedDisk* disk)
 {
@@ -291,7 +277,6 @@ bsd_read (PedDisk* disk)
 		BSDPartitionData*	bsd_part_data;
 		PedSector		start;
 		PedSector		end;
-		PedConstraint*		constraint_exact;
 
 		if (!label->d_partitions[i - 1].p_size
 		    || !label->d_partitions[i - 1].p_fstype)
@@ -308,10 +293,14 @@ bsd_read (PedDisk* disk)
 		part->num = i;
 		part->fs_type = ped_file_system_probe (&part->geom);
 
-		constraint_exact = ped_constraint_exact (&part->geom);
-		if (!ped_disk_add_partition (disk, part, constraint_exact))
+		PedConstraint *constraint_exact
+			= ped_constraint_exact (&part->geom);
+		if (constraint_exact == NULL)
 			goto error;
+		bool ok = ped_disk_add_partition (disk, part, constraint_exact);
 		ped_constraint_destroy (constraint_exact);
+		if (!ok)
+			goto error;
 	}
 
 	return 1;
@@ -350,8 +339,8 @@ bsd_write (const PedDisk* disk)
 	int			i;
 	int			max_part = 0;
 
-	PED_ASSERT (disk != NULL, return 0);
-	PED_ASSERT (disk->dev != NULL, return 0);
+	PED_ASSERT (disk != NULL);
+	PED_ASSERT (disk->dev != NULL);
 
 	bsd_specific = (BSDDiskData*) disk->disk_specific;
 	label = (BSDRawLabel *) (bsd_specific->boot_code + BSD_LABEL_OFFSET);
@@ -416,7 +405,6 @@ bsd_partition_new (const PedDisk* disk, PedPartitionType part_type,
 	}
 	return part;
 
-	free (bsd_data);
 error_free_part:
 	free (part);
 error:
@@ -449,7 +437,7 @@ bsd_partition_duplicate (const PedPartition* part)
 static void
 bsd_partition_destroy (PedPartition* part)
 {
-	PED_ASSERT (part != NULL, return);
+	PED_ASSERT (part != NULL);
 
 	if (ped_partition_is_active (part))
 		free (part->disk_specific);
@@ -479,9 +467,9 @@ bsd_partition_set_flag (PedPartition* part, PedPartitionFlag flag, int state)
 //	PedPartition*		walk; // since -Werror, this unused variable would break build
 	BSDPartitionData*	bsd_data;
 
-	PED_ASSERT (part != NULL, return 0);
-	PED_ASSERT (part->disk_specific != NULL, return 0);
-	PED_ASSERT (part->disk != NULL, return 0);
+	PED_ASSERT (part != NULL);
+	PED_ASSERT (part->disk_specific != NULL);
+	PED_ASSERT (part->disk != NULL);
 
 	bsd_data = part->disk_specific;
 
@@ -511,8 +499,8 @@ bsd_partition_get_flag (const PedPartition* part, PedPartitionFlag flag)
 {
 	BSDPartitionData*		bsd_data;
 
-	PED_ASSERT (part != NULL, return 0);
-	PED_ASSERT (part->disk_specific != NULL, return 0);
+	PED_ASSERT (part != NULL);
+	PED_ASSERT (part->disk_specific != NULL);
 
 	bsd_data = part->disk_specific;
 	switch (flag) {
@@ -616,8 +604,8 @@ bsd_alloc_metadata (PedDisk* disk)
 	PedPartition*		new_part;
 	PedConstraint*		constraint_any = NULL;
 
-	PED_ASSERT (disk != NULL, goto error);
-	PED_ASSERT (disk->dev != NULL, goto error);
+	PED_ASSERT (disk != NULL);
+	PED_ASSERT (disk->dev != NULL);
 
 	constraint_any = ped_constraint_any (disk->dev);
 
@@ -638,47 +626,17 @@ error:
 	return 0;
 }
 
-static bool
-bsd_partition_check (const PedPartition* part)
-{
-	return true;
-}
+#include "pt-common.h"
+PT_define_limit_functions (bsd)
 
 static PedDiskOps bsd_disk_ops = {
-	probe:			bsd_probe,
-#ifndef DISCOVER_ONLY
-	clobber:		bsd_clobber,
-#else
 	clobber:		NULL,
-#endif
-	alloc:			bsd_alloc,
-	duplicate:		bsd_duplicate,
-	free:			bsd_free,
-	read:			bsd_read,
-#ifndef DISCOVER_ONLY
-	write:			bsd_write,
-#else
-	write:			NULL,
-#endif
+	write:			NULL_IF_DISCOVER_ONLY (bsd_write),
 
-	partition_new:		bsd_partition_new,
-	partition_duplicate:	bsd_partition_duplicate,
-	partition_destroy:	bsd_partition_destroy,
-	partition_set_system:	bsd_partition_set_system,
-	partition_set_flag:	bsd_partition_set_flag,
-	partition_get_flag:	bsd_partition_get_flag,
-	partition_is_flag_available:	bsd_partition_is_flag_available,
 	partition_set_name:	NULL,
 	partition_get_name:	NULL,
-	partition_align:	bsd_partition_align,
-	partition_enumerate:	bsd_partition_enumerate,
-	partition_check:	bsd_partition_check,
 
-	alloc_metadata:		bsd_alloc_metadata,
-	get_max_primary_partition_count:
-				bsd_get_max_primary_partition_count,
-	get_max_supported_partition_count:
-				bsd_get_max_supported_partition_count
+	PT_op_function_initializers (bsd)
 };
 
 static PedDiskType bsd_disk_type = {
@@ -691,8 +649,8 @@ static PedDiskType bsd_disk_type = {
 void
 ped_disk_bsd_init ()
 {
-	PED_ASSERT (sizeof (BSDRawPartition) == 16, return);
-	PED_ASSERT (sizeof (BSDRawLabel) == 276, return);
+	PED_ASSERT (sizeof (BSDRawPartition) == 16);
+	PED_ASSERT (sizeof (BSDRawLabel) == 276);
 
 	ped_disk_type_register (&bsd_disk_type);
 }
